@@ -21,9 +21,7 @@ fi
 h=`sort tinylogin.links | uniq`
 
 
-rm -f $prefix/bin/tinylogin || exit 1
 mkdir -p $prefix/bin || exit 1
-install -m 4755 --owner=root --group=root tinylogin $prefix/bin/tinylogin || exit 1
 
 for i in $h ; do
 	appdir=`dirname $i`
@@ -53,5 +51,7 @@ for i in $h ; do
 	echo "  $prefix$i -> $bb_path"
 	ln $linkopts $bb_path $prefix$i || exit 1
 done
+rm -f $prefix/bin/tinylogin || exit 1
+install -m 4755 --owner=root --group=root ./tinylogin $prefix/bin/tinylogin || exit 1
 
 exit 0
