@@ -21,8 +21,8 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include "grp.h"
-#include "../tlstrings.h"
+#include "group.h"
+#include "libbb.h"
 
 struct group *getgrgid(const gid_t gid)
 {
