@@ -22,7 +22,7 @@
 #include <string.h>
 #include <errno.h>
 #include <fcntl.h>
-#include "pwd.h"
+#include "tinylogin.h"
 
 
 struct passwd *getpwnam(const char *name)
