@@ -21,7 +21,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include "pwd.h"
+#include "tinylogin.h"
 
 struct passwd *getpwuid(uid_t uid)
 {
